Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2720)

Unified Diff: Source/core/rendering/RenderLayerClipper.cpp

Issue 714933002: Set relayoutChildren to 'true' only if size change happens in Table (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: wrong patch Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/rendering/RenderLayer.cpp ('k') | Source/core/rendering/RenderLayerScrollableArea.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/rendering/RenderLayerClipper.cpp
diff --git a/Source/core/rendering/RenderLayerClipper.cpp b/Source/core/rendering/RenderLayerClipper.cpp
index ca4c8f7a2ba52eac2367e20f5efba2b127b2473b..4ef3dd0d0057c5adebe93b165e3300b06523de34 100644
--- a/Source/core/rendering/RenderLayerClipper.cpp
+++ b/Source/core/rendering/RenderLayerClipper.cpp
@@ -351,11 +351,11 @@ void RenderLayerClipper::getOrCalculateClipRects(const ClipRectsContext& context
RenderLayer* RenderLayerClipper::clippingRootForPainting() const
{
const RenderLayer* current = m_renderer.layer();
// FIXME: getting rid of current->hasCompositedLayerMapping() here breaks the
// compositing/backing/no-backing-for-clip.html layout test, because there is a
// "composited but paints into ancestor" layer involved. However, it doesn't make sense that
// that check would be appropriate here but not inside the while loop below.
- if (current->isPaintInvalidationContainer() || current->hasCompositedLayerMapping())
+ if (current->isPaintInvalidationContainer() || current->compositedLayerMapping())
return const_cast<RenderLayer*>(current);
while (current) {
« no previous file with comments | « Source/core/rendering/RenderLayer.cpp ('k') | Source/core/rendering/RenderLayerScrollableArea.cpp » ('j') | no next file with comments »
@@ -351,11 +351,11 @@ void RenderLayerClipper::getOrCalculateClipRects(const ClipRectsContext& context
{
const RenderLayer* current = m_renderer.layer();
- // FIXME: getting rid of current->hasCompositedLayerMapping() here breaks the
+ // FIXME: getting rid of current->compositedLayerMapping() here breaks the
// compositing/backing/no-backing-for-clip.html layout test, because there is a
// "composited but paints into ancestor" layer involved. However, it doesn't make sense that

Powered by Google App Engine
This is Rietveld 408576698